@@ -28,10 +28,9 @@ class MainCmd(Command):
     '''setux
     Setux commands
     '''
+    shortcut = True
     subs = dict(
-        command = CommandCmd(
-            shortcut = False,
-        ),
+        command = CommandCmd(),
         deploy = DeployCmd(),
         manage = ManageCmd(),
         method = MethodCmd(),
@@ -42,6 +41,7 @@ class ReplCmd(Command):
     '''REPL
     Setux REPL
     '''
+    shortcut = True
     def run(self):
         target = self.get('target')
         cmd = MainCmd()
@@ -61,18 +61,18 @@ class CliCmd(Command):
         repl = ReplCmd(),
         **MainCmd.subs,
     )
+    shortcut = True
 
 
 class TopCmd(Command):
     '''Setux Cli Top Command
     '''
     subs = dict(
-        config = ConfigCmd(
-            shortcut = False,
-        ),
+        config = ConfigCmd(),
         cli = CliCmd(),
         usage = UsageCmd(),
     )
+    shortcut = True
 
 
 def top():
